import { Column, Entity, JoinColumn, ManyToOne, PrimaryGeneratedColumn } from 'typeorm';
import { BaseModel } from './base.entity';
import { PostEntity } from './post.entity';
import { RestaurantEntity } from './restaurant.entity';
import { UserEntity } from './user.entity';
import { StickerEntity } from './sticker.entity';

@Entity('comment')
export class CommentEntity extends BaseModel {
  @PrimaryGeneratedColumn('identity', {
    type: 'bigint',
  })
  comment_id: string;

  @ManyToOne(() => PostEntity, (post: PostEntity) => post.post_id, {
    nullable: true,
  })
  @JoinColumn({
    name: 'post_id',
  })
  post: PostEntity;

  @Column({
    type: 'simple-json',
    default: {},
  })
  sticker: any;

  @ManyToOne(() => StickerEntity, (sticker: StickerEntity) => sticker.sticker_id, {
    nullable: true,
  })
  @JoinColumn({
    name: 'sticker_id',
  })
  sticker_id: StickerEntity;

  @ManyToOne(() => CommentEntity, (comment: CommentEntity) => comment.comment_id, {
    nullable: true,
  })
  @JoinColumn({
    name: 'parent_id',
  })
  parent: CommentEntity;

  @ManyToOne(() => UserEntity, (user: UserEntity) => user.user_id, {
    nullable: true,
  })
  @JoinColumn({
    name: 'user_id',
  })
  user: UserEntity;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  is_admin: number;

  @Column({
    type: 'text',
    default: '',
    nullable: true,
  })
  message: string;

  @Column({
    type: 'jsonb',
    array: false,
    default: () => "'[]'",
    nullable: false,
  })
  media: any;

  @Column({
    type: 'jsonb',
    array: false,
    default: () => "'[]'",
    nullable: false,
  })
  tag: any;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_like: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_love: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_haha: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_angry: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_sad: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_wow: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_nothing: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  no_of_reply: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  status: number;

  @Column({
    type: 'text',
    default: '',
    nullable: true,
  })
  thumbnail: string;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  my_reaction: number;

  @Column({
    type: 'int',
    default: 0,
    nullable: true,
  })
  is_owner: number;

  @ManyToOne(() => RestaurantEntity, (restaurant: RestaurantEntity) => restaurant.restaurant_id, {
    nullable: true,
  })
  @JoinColumn({
    name: 'restaurant_id',
  })
  restaurant_id: RestaurantEntity;
}
